import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.text.DecimalFormat;

public class EuroKonverter extends JApplet {
    private JPanel panOben, panLinksOben, panLinksUnten, panRechtsOben, panRechtsUnten, panUnten;
	private JLabel eingabeLabel, ausgabeLabel;
	private JTextField eingabeFeld, ausgabeFeld;	
    private JButton konvert;
	private int richtung = 1;

	//Wird zum Erkennung berbreiter Ausgaben bentigt:
	private FontMetrics fm;
	
	private JRadioButton euro2dm, dm2euro;
	private ButtonGroup rbGroup;

	private DecimalFormat form = new DecimalFormat("0.00");

    public void init() {
        Container cont = getContentPane();
        panOben = new JPanel();
        panOben.setLayout(new GridLayout(2, 2));
        cont.add(panOben, BorderLayout.CENTER);
		
		// Dem Unicode-Zeichen \u27a0 entspricht ein horizontaler Pfeil. 
		dm2euro = new JRadioButton("DM "+'\u27a0'+" Euro", true);
   		dm2euro.setFocusable(false);

		euro2dm = new JRadioButton("Euro "+'\u27a0'+" DM", false);
   		euro2dm.setFocusable(false);
				
		rbGroup = new ButtonGroup();
		rbGroup.add(euro2dm);
		rbGroup.add(dm2euro);
		
		RadioHandler rbHandler = new RadioHandler();
		euro2dm.addItemListener(rbHandler);
		dm2euro.addItemListener(rbHandler);

		eingabeFeld = new JTextField("", 9);
   		eingabeFeld.requestFocus();
		eingabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		eingabeLabel = new JLabel("DM");
		
		ausgabeFeld = new JTextField("", 9);
   		ausgabeFeld.setEditable(false);
   		ausgabeFeld.setFocusable(false);
   		ausgabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		ausgabeLabel = new JLabel("Euro");

		fm = getFontMetrics(getFont());
		
        konvert = new JButton("    Konvertieren    ");
        konvert.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
          		String eingabe = eingabeFeld.getText(), ausgabe;
          		if (eingabe.length() == 0) {
          			konvert.transferFocus();
          			return;
          		}
          		double factor = 1.95583;
          		if (richtung == 0) {
          			factor = 1.95583;
          		}
          		else {
          			factor = 1.0/1.95583;
          		}
      			try {
					// Dies ermglicht die Eingabe des Kommas als Dezimaltrennzeichen:
	      			eingabe = eingabe.replace(',','.');
	      			double wert = Double.parseDouble(eingabe);
	      			wert *= factor;
	      			ausgabe = form.format(wert);
	      			if (fm.stringWidth(ausgabe) <= ausgabeFeld.getWidth())
						ausgabeFeld.setText(ausgabe);
					else
						ausgabeFeld.setText("Ergebnis zu breit!");
      			} catch (Exception ex) {
					meldeFehler(ex);
      			}
				konvert.transferFocus();
				eingabeFeld.selectAll();
            }
        });
   		getRootPane().setDefaultButton(konvert);
        panUnten = new JPanel();
        panUnten.add(konvert);
   		cont.add(panUnten, BorderLayout.SOUTH);
		
		panLinksOben = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panLinksOben.add(dm2euro);
		panOben.add(panLinksOben);

		panRechtsOben = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsOben.add(eingabeFeld);
		panRechtsOben.add(eingabeLabel);
		panOben.add(panRechtsOben);

		panLinksUnten = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panLinksUnten.add(euro2dm);
		panOben.add(panLinksUnten);

		panRechtsUnten = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsUnten.add(ausgabeFeld);
		panRechtsUnten.add(ausgabeLabel);
		panOben.add(panRechtsUnten);

    }

	private void meldeFehler(Exception ex) {
		JOptionPane.showMessageDialog(this, "Fehler bei der Konvertierung: "+
		ex.toString(), "Fehler", JOptionPane.ERROR_MESSAGE);
	}

	private class RadioHandler implements ItemListener {
		public void itemStateChanged(ItemEvent e) {
			eingabeFeld.setText("");
			ausgabeFeld.setText("");
			if (e.getSource() == euro2dm) {
				eingabeLabel.setText("Euro");
				ausgabeLabel.setText("DM");
				richtung = 0;
			} else if (e.getSource() == dm2euro) {
				eingabeLabel.setText("DM");
				ausgabeLabel.setText("Euro");
				richtung = 1;
			}
		}
	}
}
