DROP DATABASE IF EXISTS Firma;

CREATE DATABASE Firma;

USE Firma;

CREATE TABLE Personal (
	PersNr INT AUTO_INCREMENT,
	Vorname VARCHAR (25) NOT NULL,
	Name VARCHAR (50) NOT NULL,
	Abteilung CHAR (1) NOT NULL,
	Strasse VARCHAR (40) NOT NULL,
	Hausnummer VARCHAR (5) NOT NULL,
	PLZ CHAR (5) NOT NULL,
	Ort VARCHAR (40) NOT NULL,
	Telefon VARCHAR(20) DEFAULT '',
	Gehalt DOUBLE NOT NULL,
	PRIMARY KEY (PersNr)
) ENGINE=INNODB;

CREATE TABLE Kunden (
	KundenNr INT AUTO_INCREMENT,
	Vorname VARCHAR (25) NOT NULL,
	Name VARCHAR (50) NOT NULL,
	Kategorie INT (2),
	Strasse VARCHAR (40) NOT NULL,
	Hausnummer VARCHAR (5) NOT NULL,
	PLZ CHAR (5) NOT NULL,
	Ort VARCHAR (40) NOT NULL,
	Telefon VARCHAR(20) NOT NULL,
	Kredit DOUBLE NOT NULL DEFAULT 0.0,
	PRIMARY KEY (KundenNr)
) ENGINE=INNODB;

CREATE TABLE Auftraege (
	AuftragsNr INT AUTO_INCREMENT,
	KundenNr INT NOT NULL,
	Datum DATE NOT NULL,
	Erledigt INT NOT NULL,
	Bezahlt INT NOT NULL,
	PRIMARY KEY (AuftragsNr),
	FOREIGN KEY (KundenNr) REFERENCES Kunden (KundenNr)
) ENGINE=INNODB;

CREATE TABLE Einsaetze (
	EinsatzNr INT AUTO_INCREMENT,
	PersNr INT NOT NULL,
	AuftragsNr INT NOT NULL,
	Dauer DOUBLE NOT NULL,
	PRIMARY KEY (EinsatzNr),
	FOREIGN KEY (PersNr) REFERENCES Personal (PersNr), 
	FOREIGN KEY (AuftragsNr) REFERENCES Auftraege (AuftragsNr)
) ENGINE=INNODB;


INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) VALUES
  ('Ulla', 'Schneider', 'B', 'Heide', '29', '51594', 'Raltop', '05123-12094', 1900.00),
  ('Otto', 'Schmidt', 'A', 'Goethegasse', '12a','52292', 'Drohntal', '07319-78129', 2490.50),
  ('Ludger', 'Mller', 'B', 'Hauptstrae', '45','53277', 'Urdorf', '04543-32212', 2260.33),
  ('Emanuel', 'Fink', 'B', 'An der Ecke', '177','54822', 'Mondorf', '03423-73212', 1693.00),
  ('Kurt', 'Schmidt', 'A', 'Sdstrasse', '23', '52292', 'Drohntal', '07319-53487', 2630.50),
  ('Monika', 'Gerber', 'C', 'Mhlenstrae', '91', '51594', 'Raltop', '05123-78123', 2600.00);

INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) VALUES
  ('Edgar', 'Eimer', 1, 'Andersweg', '7', '52434', 'Zweiweiler', '06342-13219', 5000.00),
  ('Thomas', 'Thmmes', 2, 'Kieferschlund', '23', '52434', 'Zweiweiler', '06342-542712', 2000.00),
  ('Ilse', 'Schulz', NULL, 'Oberer Waldweg', '25', '51434', 'Schnstadt', '062112-45398', 5000.00),
  ('Lutz', 'Latz', NULL, 'Dorfplatz', '79', '51434', 'Schnstadt', '06342-123412', 2000.00),
  ('Dorte', 'Lbke', 2, 'Andersweg', '56', '52434', 'Zweiweiler', '06342-77123', 3000.00),
  ('Theo', 'Rost', 2, 'Kieferschlund', '55', '52434', 'Zweiweiler', '06342-67998', 5000.00),
  ('Udo', 'Schmitt', 1, 'Oberer Waldweg', '82', '51434', 'Schnstadt', '062112-12546', 5000.00),
  ('Karl', 'Lafer', 2, 'Dorfplatz', '120', '51434', 'Schnstadt', '06342-33418', 2000.00);

INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES
  (1, '2011-03-01', 1, 0), (1, '2011-03-03', 0, 0), (2, '2011-03-13', 0, 0), (2, '2011-03-15', 0, 0),
  (2, '2011-04-15', 0, 0), (4, '2011-04-22', 1, 0), (5, '2011-04-26', 1, 0), (6, '2011-04-28', 0, 0),
  (7, '2011-05-02', 0, 0), (8, '2011-05-03', 0, 0);

INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES
  (1, 2, 6.5), (4, 2, 4), (2, 1, 7), (3, 1, 7), (4, 4, 8), (2, 2, 2.75), (1, 3, 8), (3, 1, 1.5),
  (5, 5, 3),   (5, 6, 2), (6, 7, 8), (5, 8, 4), (6, 9, 6), (6, 10,2);
