import java.sql.*;

class ResultSetDemo {
	static final String URL = "jdbc:derby:../../Firma";
	static ResultSet daten = null;
	static ResultSetMetaData metaDaten = null;
	
	static void prot(String text) {
		try {
			System.out.printf("\n"+text+"\n%-10s %-25s %-25s %10s\n",
					metaDaten.getColumnName(1), metaDaten.getColumnName(2),
					metaDaten.getColumnName(3), metaDaten.getColumnName(4));
			
			daten.absolute(0);
			while (daten.next())
				System.out.printf("%-10s %-25s %-25s %10s\n",
					daten.getInt("PersNr"), daten.getString("Vorname"),
					daten.getString("Name"), daten.getDouble("geHalt"));
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	public static void main(String args[]) {
		try (Connection verbindung = DriverManager.getConnection(URL);
			 // Frei positionierbares und Update-fhiges ResultSet
			 Statement sqlKdo = verbindung.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_UPDATABLE)) {

			daten = sqlKdo.executeQuery("SELECT * FROM Personal");
			metaDaten = daten.getMetaData();
			prot("Initial");
			
			// ndern der aktuellen Zeile
			daten.absolute(3); // Zeiger auf die dritte Zeile setzen
			daten.updateDouble("Gehalt", 7000); 
			daten.updateRow(); // Datenbank ndern
			prot("Zeile 3 gendert");
			
			// Eine Zeile einfgen
			daten.moveToInsertRow();
			daten.updateString("Vorname", "Egon");
			daten.updateString("Name", "Brgl");
			daten.updateInt("Abteilung", 1);
			daten.updateString("Strasse", "Oberer Waldweg");
			daten.updateInt("Hausnummer", 11);
			daten.updateString("PLZ", "55434");
			daten.updateString("Ort", "Graubach");
			daten.updateString("Telefon", "06342-33419");			
			daten.updateDouble("Gehalt", 1234);
			daten.insertRow();

			daten = sqlKdo.executeQuery("SELECT * FROM Personal");
			// Eine neue Abfrage aktualisiert das ResultSet, weil bei Derby die Sichtbarkeit von neu eingefgten Zeilen nciht garantiert ist
			// (derbydev.pdf, S. 72: "If the inserted row satisfies the query predicate, it may become visible in the result set.") 
			System.out.println("\nownInsertsAreVisible: "+verbindung.getMetaData().ownInsertsAreVisible(ResultSet.TYPE_SCROLL_INSENSITIVE)+"\n");
			
			prot("Neue Zeile eingefgt");
			
			// Eine Zeile lschen
			daten.last(); // Zeiger auf die letzte Zeile setzen
			daten.deleteRow();
			prot("Zeile wieder gelscht");
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
