import java.sql.*;
import javax.swing.table.*;

public class ResultSetTableModel extends AbstractTableModel {
	private Connection connection;
	private boolean connected;
	private Statement statement;
	private ResultSet resultSet;
	private ResultSetMetaData metaData;
	private int nRows;

	public ResultSetTableModel(String driver, String url, String userid,
			String passwd, String table) throws SQLException, ClassNotFoundException {
		// Datenbanktreiber laden
		if (driver.length() > 0)
			Class.forName(driver);
		
		// Verbindung zur Datenbank herstellen
		if (userid.length()  > 0)
			connection = DriverManager.getConnection(url, userid, passwd);
		else
			connection = DriverManager.getConnection(url);

		// Statement-Objekt erzeugen
		statement = connection.createStatement(
			ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_UPDATABLE);

		// SELECT ausfhren
		connected = newQuery(table);
	}

	public int getRowCount() {
		if (!connected) 
			return 0;
		else
			return nRows;
	}
   
	public int getColumnCount() {
		if (!connected)
			return 0;
		try {
			return metaData.getColumnCount(); 
		} catch (SQLException e) {
			return 0;
		}
	}

	public Object getValueAt(int row, int col) {
		if (!connected)
			return null;
		try {
			resultSet.absolute(row+1);
			return resultSet.getObject(col+1);
		} catch (SQLException e) {
			return null;
		}
	}

	public String getColumnName(int col) {
		if (!connected)
			return "";
		try {
			return metaData.getColumnName(col+1);  
		} catch (SQLException e) {
			return "";
		}
	}

	public boolean isCellEditable(int row, int col) {
		// In der ersten Spalte wird ein nicht editierbarer Primrschlssel angenommen
		if (col == 0)
			return false;
		else
			return true;
	}

	public void setValueAt(Object obj, int row, int col) {
		if (!connected)
			return;
		try {
			resultSet.absolute(row+1);
			resultSet.updateObject(col+1, obj);
			resultSet.updateRow();
		} catch (SQLException e) {
			e.printStackTrace();
			return;
		}
	}

	public boolean newQuery(String table) { 
		if (statement == null) 
			return false;
		try {
			resultSet = statement.executeQuery("SELECT * FROM "+table);
			//resultSet = statement.executeQuery("SELECT AVG(Gehalt) FROM Personal");
			
			metaData = resultSet.getMetaData();
		
			resultSet.last();
			nRows = resultSet.getRow();
		  
			fireTableStructureChanged();
			return true;
		} catch (SQLException e) {
			return false;
		}
	}

	public void disconnect() {              
		if (statement != null)
			try {                                            
				statement.close();
			} catch (Exception ignoriert) {}
		if (connection != null)
			try {                                            
				connection.close();
			} catch (Exception ignoriert) {}                               
		connected = false;              
	}
}