import java.io.*;
import java.text.*;
import java.util.*;

class FileDemo {
	public static void main(String[] args) {
		byte[] arr = {1, 2, 3};

		// Verzeichnis ggf. erstellen
		String dname = "U:/Eigene Dateien/Java/FileDemo/AusDir";
		File dir = new File(dname);
		if (dir.exists()) {
			if (dir.isDirectory())
				System.out.println("Das Verzeichnis "+dname+" existiert bereits.");
			else {
				System.out.println(dname+" existiert, ist aber kein Verzeichnis.");
				System.exit(1);
			}
		} else
			if (dir.mkdirs())
				System.out.println("Verzeichnis "+dname+" erstellt");
			else {
				System.out.println("Verzeichnis "+dname+" konnte nicht erstellt werden.");
				System.exit(1);
			}

		// Datei explizit erstellen
		String name = dname+"/Ausgabe.txt";
		File f = new File(name);
		if (!f.exists()) {
			try {
				f.createNewFile();
				System.out.println("Datei "+name+" erstellt");
			} catch (Exception e) {
				System.out.println("Fehler beim Erstellen der Datei "+name);
				System.exit(1);
			}
		}

		// Ausgabedatei ffnen und schreiben
		FileOutputStream fos = null;
		boolean error = false;
		try {
			fos = new FileOutputStream(f);
			fos.write(arr);
			System.out.println("Daten geschrieben in Datei "+name);
		} catch (Exception e) {
			System.out.println("Fehler beim Schreiben in Datei "+name);
			error = true;
		} finally {
			try {
				if (fos != null)
					fos.close();
			} catch (Exception x) {};			
		}
		if (error)
			System.exit(1);

		// ber Ausgabedatei informieren
		System.out.println("\nEigenschaften der Datei "+name);
		System.out.println("  Vollst. Pfad:       " + f.getAbsolutePath());
		DateFormat df = DateFormat.getInstance();
		String time = df.format(new Date(f.lastModified()));
		System.out.println("  Letzte Aenderung:   " + time);
		System.out.println("  Groesse in Bytes:   " + f.length());
		System.out.println("  Schreiben moeglich: " + f.canWrite()+"\n");

		// Attribute der Ausgabedatei ndern
		System.out.println("\nAenderung von Attributen der Datei "+name);
		Date d = null;
		try {
			d = df.parse("24.12.00 16:15");
		} catch (Exception e) {
			System.out.println("Fehler bei der Datumsinterpretation");
			d = new Date();
		}
		System.out.println("  Letzte Aenderung:   " + f.setLastModified(d.getTime()));
		System.out.println("  Writable(false):    " + f.setWritable(false));
		System.out.println("  Writable(true):     " + f.setWritable(true) +"\n");		
		
		// Verzeichnisinhalt auflisten
		File curDir = new File(".");
		File[] files = curDir.listFiles();
		System.out.println("Dateien im akt. Verzeichnis:");
		for (File fi : files)
			System.out.println(" "+fi.getName());
		files = curDir.listFiles(new FileFilter("java"));
		System.out.println("\nDateien im akt. Verzeichnis mit Extension .java:");
		for (File fi : files)
			System.out.println(" "+fi.getName());

		//Simput.went();

		// Nutzbares Speichervolumen ermitteln
		System.out.println("\nNutzbarer Speicher in "+dir.getAbsoluteFile()+": "+dir.getUsableSpace()/1024/1024+" MB");
		
		// Ausgabedatei umbenennen
		File fn = new File(dname+"/Rausgabe.txt");
		if (f.renameTo(fn))
			System.out.println("\nDatei "+f.getName()+" umbenannt in "+fn.getName());
		else {
			System.out.println("Fehler beim Umbenennen der Datei "+f.getName());
			fn = f;
		}

		// Ausgabedatei lschen
		if (fn.delete())
			System.out.println("Datei "+fn.getName()+" geloescht");
		else {
			System.out.println("Fehler beim Loeschen der Datei "+fn.getName());
			System.exit(1);
		}

		// Verzeichnis lschen
		if (dir.delete())
			System.out.println("Verzeichnis "+dir.getName()+" geloescht");
		else {
			System.out.println("Fehler beim Loeschen des Ordners "+dir.getName());
			System.exit(1);
		}
	}
}