import java.io.*;
import java.nio.file.*;
import java.nio.file.attribute.*;
import java.util.*;

class FilesAndFolders {
   
    static void printFileStore(FileStore store) throws IOException {
        final long K = 1024;
    	long total = store.getTotalSpace() / K;
        long used = (store.getTotalSpace() - store.getUnallocatedSpace()) / K;
        long avail = store.getUsableSpace() / K;

        String s = store.toString();
        if (s.length() > 20) {
            System.out.println(s);
            s = "";
        }
        System.out.format("%-20s %12d %12d %12d\n", s, total, used, avail);
    }
	
	public static void main(String[] args) {
		byte[] arr = {1, 2, 3};

		Path dir = Paths.get("U:", "Eigene Dateien", "Java", "NioFile", "Ort");
		
		// Sich spter auf ein Testergebnis zu verlassen, ist unsicher (TOCTTOU-Falle)!
		if (Files.exists(dir))
			System.out.println(dir+" existiert bereits.");
		else
			if (Files.notExists(dir))
				System.out.println(dir+" existiert noch nicht");
			else
				System.out.println(dir+" hat einen unbekannten Status.");

		// Verzeichnis ggf. erstellen
		try {
			Files.createDirectories(dir);
		} catch (FileAlreadyExistsException ae) {
			if (Files.isDirectory(dir))
				System.err.println("Das Verzeichnis "+dir+" existiert bereits.");
			else {
				System.err.println(dir+" existiert, ist aber kein Verzeichnis.");
				System.exit(1);
			}
		} catch (IOException ioe) {
			System.err.println(ioe);
			System.exit(1);
		}
		
		// Datei explizit erstellen
		Path file = dir.resolve("Ausgabe.txt");
		try {
			Files.createFile(file);
		} catch (FileAlreadyExistsException ae) {
			System.err.println(file + " existiert bereits.");
		} catch (IOException ioe) {
			System.err.println(ioe);
			System.exit(1);
		}
		try {
			Files.createTempFile(null, null);
		} catch (IOException ioe) {
			System.err.println(ioe);
		}		
		
		// Daten in die Ausgabedatei schreiben
		try {
			Files.write(file,  arr);
			System.out.println("Daten geschrieben in Datei "+file);
		} catch (IOException e) {
			System.out.println("Fehler beim Schreiben in Datei "+file);
		}

		// ber ein Dateisystemobjekt informieren
		System.out.println("\nEigenschaften von    " + file);
//		file = Paths.get("E:", "Daten", "LWU", "Eigene Dateien", "Java", "NioFile", "Ort", "Ausgabe.txt");
		try {
//			BasicFileAttributes attr = Files.readAttributes(file, BasicFileAttributes.class);
//			BasicFileAttributes attr = Files.readAttributes(name, BasicFileAttributes.class, LinkOption.NOFOLLOW_LINKS);
//			System.out.println(" Groesse in Bytes:   " + attr.size());
			System.out.println(" Groesse in Bytes:   " + Files.size(file));
			System.out.println(" Letzte Aenderung:   " + Files.getLastModifiedTime(file));
			System.out.println(" Datei:              " + Files.isRegularFile(file));
			System.out.println(" Verzeichnis:        " + Files.isDirectory(file));
			System.out.println(" Schreiben moeglich: " + Files.isWritable(file));
//			System.out.println(" Symb. Link:        " + attr.isSymbolicLink(name));
		} catch (Exception e) {
			System.err.println(e);
		}

		// Datum der letzten Modifikation ndern
		try {
			System.out.println("\nDatum der letzten Modifikation setzen\n vorher:    " + Files.getLastModifiedTime(file));
			Calendar cal = Calendar.getInstance();
			cal.set(1980, Calendar.APRIL, 1, 0, 0, 0);
			Files.setLastModifiedTime(file, FileTime.fromMillis(cal.getTimeInMillis()));
			System.out.println(" nachher:   " + Files.getLastModifiedTime(file));
		} catch (Exception e) {
			System.err.println(e);
		}

		// Datei kopieren
		try {
			Files.copy(file, dir.resolve("Kopie.txt"));
		} catch (Exception e) {
			System.err.println(e);
		}
		
		// Datei umbenennen
		try {
			Files.move(file, file.resolveSibling("Umbenannt.txt"));
			System.out.println("\nDatei " + file + " umbenannt");
		} catch (Exception e) {
			System.err.println(e);
		}

		// Datei verschieben
		try {
			Files.move(dir.resolve("Umbenannt.txt"), dir.getParent().resolve("Verschoben.txt"), StandardCopyOption.REPLACE_EXISTING);
			System.out.println("\nDatei " + dir.resolve("Umbenannt.txt") + " verschoben");			
		} catch (Exception e) {
			System.err.println(e);
		}
		
		// Verzeichnisinhalte auflisten
		System.out.println("\nDateien im Verzeichnis "+dir);
		try (DirectoryStream<Path> stream = Files.newDirectoryStream(dir)) {
		    for (Path path: stream)
		        System.out.println(path.getFileName());
		} catch (Exception e) {
			System.err.println(e);
		}
		
		// Dateien lschen
		try (DirectoryStream<Path> stream = Files.newDirectoryStream(dir)) {
			System.out.println("\nDateien loeschen:");
			for (Path path: stream) {
				Files.delete(path);
				System.out.println(" "+path);
			}
		} catch (Exception e) {
			System.err.println(e);
		}

		// Verzeichnis lschen
		try {
			Files.delete(dir);
			System.out.println("\nVerzeichnis geloescht");			
		} catch (Exception e) {
			System.err.println(e);
		}
		
		// Nutzbares Speichervolumen ermitteln
        System.out.format("\n%-20s %12s %12s %12s\n", "Filesystem", "kbytes", "used", "avail");
        FileSystem fs = FileSystems.getDefault();
		try {
	        for (FileStore store: fs.getFileStores())
	        	printFileStore(store);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}