import java.util.concurrent.*;

public class MaxSinFinder {
	static private ForkJoinPool pool = new ForkJoinPool();
	
	private MaxSinFinder() {}
	
	static public int findeMax(double[] daten, int schwelle) {
		MaxTask task = new MaxTask(daten, 0, daten.length, schwelle);
		pool.invoke(task);
		return  task.join();
	}
	
	static public int findeMax(double[] daten) {
		return findeMax(daten, daten.length/Runtime.getRuntime().availableProcessors());
	}
	
	static class MaxTask extends RecursiveTask<Integer> {
		private double[] daten;
		private int schwelle;
		private int start, ende;
		private int maxInd;
		
		public MaxTask(double[] daten, int start, int ende, int schwelle) {
			this.daten = daten;
			this.start = start;
			this.ende = ende; 
			this.schwelle = schwelle;
		}
		
		public int findeMax(int start, int ende) {
			int maxInd = start;
			double aktMax = Math.sin(daten[start]);
			for (int i = start+1; i < ende; i++) {
			    double kand = Math.sin(daten[i]);
			    if (kand > aktMax) {
			        aktMax = kand; 
			    	maxInd = i;
			    }
			}
			return maxInd;
		}
		
		protected Integer compute() {
			int umfang = ende - start; 
			if (umfang <= schwelle)
				maxInd = findeMax(start, ende);
			else {
				int haelfte = umfang/2;
				MaxTask task1 = new MaxTask(daten, start, start+haelfte, schwelle);
				MaxTask task2 = new MaxTask(daten, start+haelfte, ende, schwelle);
				task2.fork();
				int erg1 = task1.compute();
				int erg2 = task2.join();
				maxInd = Math.sin(daten[erg2]) > Math.sin(daten[erg1]) ? erg2 : erg1;
			}
			return maxInd;
		}
	}
}