import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

class SwingWorkerDemo extends JFrame {
	private final static String labelPrefix = "Zhlerstand: ";
	private JLabel lblCounter, lblRandom;
	private JPanel panCenter;
	private JButton cbCount, cbWorker;
	private int numClicks = 0;
	private final int anz = 100_000_000;

	SwingWorkerDemo() {
		super("SwingWorker");
		Container cont = getContentPane();

		cbCount = new JButton("Zhlerstand erhhen");
		getRootPane().setDefaultButton(cbCount);
		cbCount.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				numClicks++;
				lblCounter.setText(labelPrefix + numClicks);
			}
		});

		cbWorker = new JButton("Mittel von "+anz+" Zufallszahlen");
		cbWorker.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				lblRandom.setText("Berechnung luft ...");
				RandomNumberCruncher worker = new RandomNumberCruncher();
				worker.execute();
			}
		});
		
		lblCounter = new JLabel(labelPrefix + "0    ");
		Font f = new Font("SansSerif", Font.BOLD, 16);
		lblCounter.setFont(f);

		lblRandom = new JLabel();
		lblRandom.setFont(f);
		
		panCenter = new JPanel();
		panCenter.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		panCenter.setLayout(new GridLayout(0, 1));
		panCenter.add(cbCount);
		panCenter.add(lblCounter);
		panCenter.add(lblRandom);
		panCenter.add(cbWorker);
		cont.add(panCenter, BorderLayout.CENTER);

		setMinimumSize(new Dimension(500, 200));		
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	private class RandomNumberCruncher extends SwingWorker<Double, Void> {
		private double d;

		public Double doInBackground() {
			for (int i = 0; i < anz; i++)
				d += Math.random();
			return new Double(d/anz);
		}

		public void done() {
			try {
				lblRandom.setText("Mittelwert der Zufallszahlen: "+get());
			} catch (Exception e) {
				JOptionPane.showMessageDialog(null, "Berechnung gescheitert");
			}
		}
	}

	public static void main(String args[]) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				SwingWorkerDemo sts = new SwingWorkerDemo();
				sts.setVisible(true);
			}
		});
	}
}

