import java.awt.*;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.StringSelection;
import java.awt.datatransfer.Transferable;
import javax.swing.*;

class JListDnD extends JFrame {
	private JList listeLinks, listeRechts;
	private final static String titel = "JList Drag&Drop";
	private DefaultListModel modelLinks, modelRechts;
	
	JListDnD() {
		super(titel);
		Container cont = getContentPane();
		cont.setLayout(new GridLayout(1,0,10,0));
	
		modelLinks = new DefaultListModel();
		modelLinks.addElement("Emma"); modelLinks.addElement("Wolle");
		modelLinks.addElement("Brina");
		listeLinks = new JList(modelLinks);
		listeLinks.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		// Dieser Aufruf sorgt, dafr, dass das JList-Objekt die Drag-Geste erkennt:
		listeLinks.setDragEnabled(true);
		listeLinks.setDropMode(DropMode.ON_OR_INSERT);

		modelRechts = new DefaultListModel();
		modelRechts.addElement("Diego");
		listeRechts = new JList(modelRechts);
		listeRechts.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		listeRechts.setDragEnabled(true);
		listeRechts.setDropMode(DropMode.ON_OR_INSERT);

		JScrollPane jspLinks = new JScrollPane(listeLinks);
		jspLinks.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		JScrollPane jspRechts = new JScrollPane(listeRechts);
		jspRechts.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));

		cont.add(jspLinks, BorderLayout.WEST);
		cont.add(jspRechts, BorderLayout.EAST);

		ListTransferHandler lth = new ListTransferHandler();
		listeLinks.setTransferHandler(lth);
		listeRechts.setTransferHandler(lth);
		
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setMinimumSize(new Dimension(240, 130));
		setVisible(true);
	}
	
	public static void main(String[] args) {
		new JListDnD();
	}

	private class ListTransferHandler extends TransferHandler {
		private JList quellListe, zielListe;
		private int quellIndex, zielIndex;
		
		public int getSourceActions(JComponent quelle) {
			return TransferHandler.COPY_OR_MOVE;
		}
	
		protected Transferable createTransferable(JComponent quelle) {
			quellListe = (JList) quelle;
			quellIndex = quellListe.getSelectedIndex(); 
			return new StringSelection((String) quellListe.getSelectedValue());
		}
	    
		protected void exportDone(JComponent quelle, Transferable data, int action) {
			if (action == TransferHandler.MOVE) {
				if (zielListe == quellListe  &&  zielIndex < quellIndex)
					quellIndex++;
				quellListe = (JList) quelle;
				((DefaultListModel) quellListe.getModel()).remove(quellIndex);
			}
		}
	
		public boolean canImport(TransferHandler.TransferSupport info) {
			if (info.isDataFlavorSupported(DataFlavor.stringFlavor))
				return true;
			else
				return false;
		}
	    
		public boolean importData(TransferHandler.TransferSupport info) {
			JList.DropLocation dl = (JList.DropLocation) info.getDropLocation();
			zielListe = (JList) info.getComponent();
			
			// Model-Objekt zur Ziel-Liste ermitteln
			DefaultListModel listModel = (DefaultListModel) zielListe.getModel();
			// An welcher Position soll eingefgt werden?
			zielIndex = dl.getIndex();
			
			// Daten bernehmen und einfgen
			Transferable t = info.getTransferable();
			String element;
			try {
				element = (String) t.getTransferData(DataFlavor.stringFlavor);
			} catch (Exception e) { return false; }
			listModel.add(zielIndex, element);

			return true;
		}
	}
}