import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.filechooser.*;

import java.io.*;

class Editor extends JFrame{
	private JMenuBar menuBar;
	private JMenu fileMenu, toolsMenu, fontMenu;
	private JEditorPane text;
	private File file;
	private JMenuItem openItem, exitItem, timesItem, arialItem, colorItem;
	private final static String titel = "Editor - mit Symbolleiste";
	
	public Editor() {
		super(titel);

		text = new JEditorPane();
		text.setDragEnabled(true);
		text.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 14));
		getContentPane().add(new JScrollPane(text), BorderLayout.CENTER);
		
		menuBar = new JMenuBar();
		setJMenuBar(menuBar);
		
		fileMenu = new JMenu("Datei");
		fileMenu.setMnemonic(KeyEvent.VK_D);
		menuBar.add(fileMenu);
		
		openItem = new JMenuItem("ffnen");
		openItem.setMnemonic(KeyEvent.VK_F);
		openItem.setIcon(new ImageIcon("open.gif"));
		fileMenu.add(openItem);
		openItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					getFileName();
					if (file != null) readText();
				}
			});

		// Trennline zwischen Meneintrgen
		fileMenu.addSeparator();
		
		exitItem = new JMenuItem("Beenden");
		exitItem.setMnemonic(KeyEvent.VK_B);
		exitItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					System.exit(0);
				}
			});
		fileMenu.add(exitItem);

		toolsMenu = new JMenu("Extras");
		toolsMenu.setMnemonic(KeyEvent.VK_E);
		fontMenu = new JMenu("Schriftart");
		fontMenu.setMnemonic(KeyEvent.VK_S);
		fontMenu.setIcon(new ImageIcon("font.gif"));
		toolsMenu.add(fontMenu);

		timesItem = new JRadioButtonMenuItem("Times-Roman");
		timesItem.setMnemonic(KeyEvent.VK_T);
		timesItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					timesItem.setSelected(true);
					arialItem.setSelected(false);
					text.setFont(new Font(Font.SERIF, Font.PLAIN, 14));
				}
			});
		fontMenu.add(timesItem);

		arialItem = new JRadioButtonMenuItem("Arial");
		arialItem.setMnemonic(KeyEvent.VK_A);
		arialItem.setSelected(true);
		arialItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					arialItem.setSelected(true);
					timesItem.setSelected(false);
					text.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 14));
				}
			});
		fontMenu.add(arialItem);

		menuBar.add(toolsMenu);

		colorItem = new JMenuItem("Hintergrundfarbe");
		colorItem.setMnemonic(KeyEvent.VK_H);
		colorItem.setIcon(new ImageIcon("color.gif"));
		toolsMenu.add(colorItem);
		colorItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					Color tempColor = 
						JColorChooser.showDialog(text,
								"Whlen Sie eine Hintergrundfarbe.", text.getBackground());
					if (tempColor != null)
						text.setBackground(tempColor);
				}
			});
		menuBar.add(toolsMenu);
		
		// Symbolleiste erstellen
		JToolBar toolBar = new JToolBar("Editor");
		getContentPane().add(toolBar, BorderLayout.NORTH);
		menuBar.setBorder(BorderFactory.createEtchedBorder());
		// toolBar.setFloatable(false);
		
		JButton openButton = new JButton(new ImageIcon("open.gif"));
		openButton.addActionListener(openItem.getActionListeners()[0]);
		toolBar.add(openButton);
		toolBar.addSeparator();
		JButton exitButton = new JButton("Beenden");
		exitButton.addActionListener(exitItem.getActionListeners()[0]);
		toolBar.add(exitButton);
		toolBar.addSeparator();

		JButton colorButton = new JButton(new ImageIcon("color.gif"));
		colorButton.addActionListener(colorItem.getActionListeners()[0]);
		toolBar.add(colorButton);
		
		addWindowListener(new WindowAdapter() {
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});
		setSize(300, 200);
		setVisible(true);
		text.requestFocus();
	}

	private void getFileName() {
		FileNameExtensionFilter filter = 
			new FileNameExtensionFilter("Textdatei (*.txt)", "txt");
		JFileChooser fc = new JFileChooser();
		fc.addChoosableFileFilter(filter);
		if (fc.showOpenDialog(this) == JFileChooser.APPROVE_OPTION)
			file = fc.getSelectedFile();
	}

	private void readText() {
		try (BufferedInputStream bis = new BufferedInputStream(new FileInputStream(file)) ) {
			text.read(bis, null);
		} catch (Exception e) {
			JOptionPane.showMessageDialog(this,
				"Fehler beim Lesen:\n"+e, "Fehler",
				 JOptionPane.ERROR_MESSAGE);
		}
	}
	
	public static void main(String[] arg) {
		new Editor();
	}
}