import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.filechooser.*;

import java.io.*;

enum FileDialogType {OPEN, SAVE}

class Editor extends JFrame{
	private JMenuBar menuBar;
	private JMenu fileMenu, toolsMenu, fontMenu, lafMenu;
	private JEditorPane text;
	private File file;
	private JFileChooser fc;
	private JMenuItem openItem, saveItem, saveAsItem, exitItem, timesItem, arialItem, colorItem;
	private JMenuItem[] lafItems;
	private UIManager.LookAndFeelInfo[] lafs;
	private final static String titel = "Editor - mit Look & Feel";
	
	public Editor() {
		super(titel);

		text = new JEditorPane();
		text.setDragEnabled(true);
		text.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 14));
		getContentPane().add(new JScrollPane(text), BorderLayout.CENTER);

		// JFileChooser vorbereiten
		FileNameExtensionFilter filter = 
			new FileNameExtensionFilter("Textdatei (*.txt)", "txt");
		fc = new JFileChooser();
		fc.addChoosableFileFilter(filter);
		
		menuBar = new JMenuBar();
		setJMenuBar(menuBar);
		
		fileMenu = new JMenu("Datei");
		fileMenu.setMnemonic(KeyEvent.VK_D);
		menuBar.add(fileMenu);
		
		openItem = new JMenuItem("ffnen");
		openItem.setMnemonic(KeyEvent.VK_F);
		openItem.setIcon(new ImageIcon("open.gif"));
		fileMenu.add(openItem);
		openItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					ask4File(FileDialogType.OPEN);
					if (file != null)
						readText();
				}
			});

		saveItem = new JMenuItem("Sichern");
		saveItem.setMnemonic(KeyEvent.VK_S);
		saveItem.setIcon(new ImageIcon("save.gif"));		
		fileMenu.add(saveItem);
		saveItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (file == null)
						ask4File(FileDialogType.SAVE);
					writeText();
				}
			});

		saveAsItem = new JMenuItem("Sichern unter");
		saveAsItem.setMnemonic(KeyEvent.VK_U);
		saveAsItem.setIcon(new ImageIcon("saveAs.gif"));		
		fileMenu.add(saveAsItem);
		saveAsItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					ask4File(FileDialogType.SAVE);
					if (file != null) {
						writeText();
					}
				}
			});
		
		// Trennline zwischen Meneintrgen
		fileMenu.addSeparator();
		
		exitItem = new JMenuItem("Beenden");
		exitItem.setMnemonic(KeyEvent.VK_B);
		exitItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					System.exit(0);
				}
			});
		fileMenu.add(exitItem);

		toolsMenu = new JMenu("Extras");
		toolsMenu.setMnemonic(KeyEvent.VK_E);
		fontMenu = new JMenu("Schriftart");
		fontMenu.setMnemonic(KeyEvent.VK_S);
		fontMenu.setIcon(new ImageIcon("font.gif"));
		toolsMenu.add(fontMenu);

		timesItem = new JRadioButtonMenuItem("Times-Roman");
		timesItem.setMnemonic(KeyEvent.VK_T);
		timesItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					timesItem.setSelected(true);
					arialItem.setSelected(false);
					text.setFont(new Font(Font.SERIF, Font.PLAIN, 14));
				}
			});
		fontMenu.add(timesItem);

		arialItem = new JRadioButtonMenuItem("Arial");
		arialItem.setMnemonic(KeyEvent.VK_A);
		arialItem.setSelected(true);
		arialItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					arialItem.setSelected(true);
					timesItem.setSelected(false);
					text.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, 14));
				}
			});
		fontMenu.add(arialItem);

		lafMenu = new JMenu("Look & Feel");
		lafs = UIManager.getInstalledLookAndFeels();
		lafItems = new JMenuItem[lafs.length];
		UIActionHandler uah = new UIActionHandler(); 
		for (int i = 0; i< lafs.length; i++) {
			lafItems[i] = new JMenuItem(lafs[i].getName());
			lafItems[i].addActionListener(uah);
			lafMenu.add(lafItems[i]);
		}
		toolsMenu.add(lafMenu);

		menuBar.add(toolsMenu);

		colorItem = new JMenuItem("Hintergrundfarbe");
		colorItem.setMnemonic(KeyEvent.VK_H);
		colorItem.setIcon(new ImageIcon("color.gif"));
		toolsMenu.add(colorItem);
		colorItem.addActionListener(new	ActionListener() {
				public void actionPerformed(ActionEvent e) {
					Color tempColor = 
						JColorChooser.showDialog(text,
								"Whlen Sie eine Hintergrundfarbe.", text.getBackground());
					if (tempColor != null)
						text.setBackground(tempColor);
				}
			});
		menuBar.add(toolsMenu);
		
		// Symbolleiste erstellen
		JToolBar toolBar = new JToolBar("Editor");
		getContentPane().add(toolBar, BorderLayout.NORTH);
		menuBar.setBorder(BorderFactory.createEtchedBorder());
		// toolBar.setFloatable(false);
		
		JButton openButton = new JButton(new ImageIcon("open.gif"));
		openButton.addActionListener(openItem.getActionListeners()[0]);
		toolBar.add(openButton);

		toolBar.addSeparator();

		JButton saveButton = new JButton(new ImageIcon("save.gif"));
		saveButton.addActionListener(saveItem.getActionListeners()[0]);
		toolBar.add(saveButton);
		
		toolBar.addSeparator();

		JButton colorButton = new JButton(new ImageIcon("color.gif"));
		colorButton.addActionListener(colorItem.getActionListeners()[0]);
		toolBar.add(colorButton);
		
		// JFrame-Vorbereituzng
		addWindowListener(new WindowAdapter() {
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});
		setSize(300, 200);
		setVisible(true);
		text.requestFocus();		
	}

	private void ask4File(FileDialogType type) {
		int returnCode;
		if (type == FileDialogType.OPEN)
			returnCode = fc.showOpenDialog(this);
		else
			returnCode = fc.showSaveDialog(this);
		if (returnCode == JFileChooser.APPROVE_OPTION) {
			file = fc.getSelectedFile();
			if (!file.getName().endsWith(".txt") && !file.exists())
				file = new File(file.getPath()+".txt");
		}
	}
	
	private void readText() {
		try (BufferedInputStream bis = new BufferedInputStream(new FileInputStream(file)) ) {
			text.read(bis, null);
		} catch (Exception e) {
			JOptionPane.showMessageDialog(this,
				"Fehler beim Lesen:\n"+e, "Fehler",
				 JOptionPane.ERROR_MESSAGE);
		}
	}
	
	private void writeText() {
		try (PrintWriter pw = new PrintWriter(new BufferedWriter(new FileWriter(file))) ) {
			text.write(pw);
		} catch (Exception e) {
			JOptionPane.showMessageDialog(this,
				"Fehler beim Schreiben:\n"+e, "Fehler",
				 JOptionPane.ERROR_MESSAGE);
		}
	}
	
	private class UIActionHandler implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			for (int i = 0; i < lafs.length; i++) {
				if (e.getSource() == lafItems[i])
					try {
						UIManager.setLookAndFeel(lafs[i].getClassName());
						SwingUtilities.updateComponentTreeUI(Editor.this);
					} catch (Exception ex) {
						JOptionPane.showMessageDialog(text, "Fehler beim UI-Management", titel, JOptionPane.ERROR_MESSAGE);
					}
			}
		}
	}
	
	public static void main(String[] arg) {
		new Editor();
	}
}