import javax.swing.*;

import java.awt.*;
import java.awt.event.*;
import java.text.DecimalFormat;

enum Richtung {DM2EURO, EURO2DM};

class EuroKonverter extends JFrame {
	private JLabel lblEingabe, lblAusgabe;
	private JTextField tfEingabe, tfAusgabe;	
	private JPanel panLinksUnten, panLinksMitte, panLinksOben, panRechtsOben, panRechtsMitte, panRechtsUnten;
	private JButton cbBeenden, cbKonvertieren;

	private Richtung richtung = Richtung.DM2EURO;

	//Wird zum Erkennung berbreiter Ausgaben bentigt:
	private FontMetrics fm;
	private int maxAusgabeBreite;
	
	private JRadioButton euro2dm, dm2euro;
	private ButtonGroup rbGroup;

	private DecimalFormat form = new DecimalFormat("0.00");

    EuroKonverter() {
        super("Euro-Konverter");
        Container cont = getContentPane();
        cont.setLayout(new GridLayout(3, 2));
		
		// Dem Unicode-Zeichen \u27a0 entspricht ein horizontaler Pfeil. 
		dm2euro = new JRadioButton("DM "+'\u27a0'+" Euro", true);
   		dm2euro.setFocusable(false);

		euro2dm = new JRadioButton("Euro "+'\u27a0'+" DM", false);
   		euro2dm.setFocusable(false);
				
		rbGroup = new ButtonGroup();
		rbGroup.add(euro2dm);
		rbGroup.add(dm2euro);
		
		RadioHandler rbHandler = new RadioHandler();
		euro2dm.addItemListener(rbHandler);
		dm2euro.addItemListener(rbHandler);

        cbBeenden = new JButton("Ende");
   		cbBeenden.setFocusable(false);
        cbBeenden.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                System.exit(0);
            }
        });

		tfEingabe = new JTextField("", 9);
   		tfEingabe.requestFocus();
		tfEingabe.setHorizontalAlignment(JTextField.RIGHT);
		lblEingabe = new JLabel("DM");
		
		tfAusgabe = new JTextField("", 9);
   		tfAusgabe.setEditable(false);
   		tfAusgabe.setFocusable(false);
   		tfAusgabe.setHorizontalAlignment(JTextField.RIGHT);
		lblAusgabe = new JLabel("Euro");

        cbKonvertieren = new JButton("  Konvertieren  ");
        cbKonvertieren.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
          		String eingabe = tfEingabe.getText(), ausgabe;
          		if (eingabe.length() == 0) {
          			//cbKonvertieren.transferFocus();
          			tfEingabe.requestFocus();
          			return;
          		}
          		double factor = 1.95583;
          		if (richtung == Richtung.EURO2DM) {
          			factor = 1.95583;
          		}
          		else {
          			factor = 1.0/1.95583;
          		}
      			try {
					// Dies ermglicht die Eingabe des Kommas als Dezimaltrennzeichen:
	      			eingabe = eingabe.replace(',','.');
	      			double wert = Double.parseDouble(eingabe);
	      			wert *= factor;
	      			ausgabe = form.format(wert);
	      			if (fm.stringWidth(ausgabe) <= maxAusgabeBreite)
						tfAusgabe.setText(ausgabe);
					else
						tfAusgabe.setText("Ergebnis zu breit!");
      			} catch (Exception ex) {
					meldeFehler(ex);
      			}
				cbKonvertieren.transferFocus();
				tfEingabe.selectAll();
            }
        });
   		getRootPane().setDefaultButton(cbKonvertieren);
		
		panLinksOben = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panLinksOben.add(dm2euro);
		cont.add(panLinksOben);

		panRechtsOben = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsOben.add(tfEingabe);
		panRechtsOben.add(lblEingabe);
		cont.add(panRechtsOben);

		panLinksMitte = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panLinksMitte.add(euro2dm);
		cont.add(panLinksMitte);

		panRechtsMitte = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsMitte.add(tfAusgabe);
		panRechtsMitte.add(lblAusgabe);
		cont.add(panRechtsMitte);

		panLinksUnten = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panLinksUnten.add(cbBeenden);
		cont.add(panLinksUnten);

		panRechtsUnten = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsUnten.add(cbKonvertieren);
		cont.add(panRechtsUnten);

		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        pack();
        setResizable(false);
        setVisible(true);

		//Wird zum Erkennung berbreiter Ausgaben bentigt:
		fm = getFontMetrics(getFont());
		maxAusgabeBreite = tfAusgabe.getWidth();
    }

	private void meldeFehler(Exception ex) {
		JOptionPane.showMessageDialog(this, "Fehler bei der Konvertierung: "+
		ex.toString(), "Fehler", JOptionPane.ERROR_MESSAGE);
	}

    public static void main(String[] args) {
        new EuroKonverter();
    }

	class RadioHandler implements ItemListener {
		public void itemStateChanged(ItemEvent e) {
			tfEingabe.setText("");
			tfAusgabe.setText("");
			if (e.getSource() == euro2dm) {
				lblEingabe.setText("Euro");
				lblAusgabe.setText("DM");
				richtung = Richtung.EURO2DM;
			} else if (e.getSource() == dm2euro) {
				lblEingabe.setText("DM");
				lblAusgabe.setText("Euro");
				richtung = Richtung.DM2EURO;
			}
		}
	}
}
