import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

class MPC extends JFrame {
	private final static String labelPrefix = "Zhlerstand: ";
	private final static String titel = "Multi Purpose Counter";
	private JLabel lblText;
	private JPanel panLeft;
	private JButton cbCount;
	private int numClicks = 0;
	private final byte maxIcon = 3;
	private ImageIcon[] icons;
	private JLabel lblIcon;
	private byte iconInd = 0;

	MPC() {
		// ber den Basisklassen-Konstruktor erhlt das Rahmenfenster einen Titel.
		super(titel);
		
		// cont ist eine bequeme Referenz auf die Inhaltsschicht des JFrame-Fensters
		Container cont = getContentPane();
		// System.out.println(cont.getClass());
		
		// JLabel-Komponente mit Text initialisieren
		lblText = new JLabel(labelPrefix + "0");
		lblText.setToolTipText("Label mit Text");
		
		// Icons erzeugen
		icons = new ImageIcon[maxIcon];
		icons[0] = new ImageIcon("duke.gif");
		icons[1] = new ImageIcon("fight.gif");
		icons[2] = new ImageIcon("snooze.gif");
		
		// JLabel mit Icon initialisieren
		lblIcon = new JLabel(icons[0]);
		lblIcon.setToolTipText("Label mit Icon");

		// JButton-Komponente initilisieren
		cbCount = new JButton("Zhlerstand erhhen");
		// Der Schalter kann auch mit <Alt><S> ausgelst werden.
		cbCount.setMnemonic(KeyEvent.VK_S);
		// Der Schalter kann als Default Button auch mit Enter ausgelst werden.
		getRootPane().setDefaultButton(cbCount);
		cbCount.setToolTipText("Befehlsschalter");

		// JPanel-Komponente erzeugen.
		// Dieser "immediate container" dient zur Positionierung von Komponenten.
		panLeft = new JPanel();
		
		// Der Container wird "frei gestellt".
		panLeft.setBorder(BorderFactory.createEmptyBorder(30, 30, 30, 30));
		
		// Layout-Manager fr die JPanel-Komponente erzeugen
		// Hier wird dafr gesorgt, dass alle Komponentn in einer Spalte stehen.
		panLeft.setLayout(new GridLayout(0, 1));
		
		// Der JButton und das Text-JLabel werden auf die JPanel-Komponente gesetzt.
		panLeft.add(cbCount);
		panLeft.add(lblText);
		
		// Der JPanel-Container wird auf den JFrame gesetzt (Position: Mitte).
		cont.add(panLeft, BorderLayout.CENTER);
		// add(panLeft, BorderLayout.CENTER); // Der Aufruf wird an die Inhaltsschicht weitergereicht.

		// Das Icon-Label wird auf den JFrame gesetzt (Position: Osten, also rechter Rand).
		cont.add(lblIcon, BorderLayout.EAST);
		
		// Fr den JButton wird ein ActionListener registriert.
		// Dazu wird eine anonyme Klasse an Ort und Stelle definiert.
		cbCount.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				numClicks++;
				lblText.setText(labelPrefix + numClicks);
				if (iconInd < maxIcon-1)
					iconInd++;
				else
					iconInd = 0;
				lblIcon.setIcon(icons[iconInd]);
			}
		  });
		
		// Der JFrame erhlt einen Handler fr Fenster-Ereignisse.
		addWindowListener(new WC());
		
		// Diese Methode verhindert ein Schlieen unter Miachtung des WindowListeners
		setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		
		// initiale JFrame-Gre festlegen
		setSize(340, 150);
		
		// JFrame anzeigen
		setVisible(true);
//		System.out.println(cont.getClass());
//		System.out.println(getGlassPane().getClass());
	}

	public static void main(String[] args) {
		new MPC();
	}

	// Der WindowListener fr den JFrame (= top level container) wird als interne Klasse definiert.
	private class WC extends WindowAdapter {
		public void windowClosing(WindowEvent e) {
			if (JOptionPane.showConfirmDialog(e.getWindow(), 
				  "Wollen Sie nach "+ numClicks +
				  " Klicks wirklich schon aufhren?", 
				  titel, JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
				System.exit(0);
		}
	}
}
